Release History
---------------

0.1.1 (2013-12-31)
^^^^^^^^^^^^^^^^^^

- Fixed not working previous release
- Changed example.py


0.1.0 (2013-12-30)
^^^^^^^^^^^^^^^^^^

- ``BaseThrottler`` a simple throttler with a fixed amount of delay
